@@ -356,7 +356,7 @@ def description_tag
 end
 
 def jquery_tag
-	%Q[<script src="//ajax.googleapis.com/ajax/libs/jquery/3.0.0/jquery.min.js"></script>]
+	%Q[<script src="//ajax.googleapis.com/ajax/libs/jquery/3.2.1/jquery.min.js"></script>]
 end
 
 enable_js( '00default.js', async: false )
@@ -715,8 +715,7 @@ def comment_mail_send
 	rescue
 		rmail = File::open( "#{TDiary::PATH}/../views/mail.rtxt" ){|f| f.read }
 	end
-	text = @conf.to_mail( ERB::new( rmail.untaint ).result( binding ) )
-	receivers.each(&:untaint)
+	text = @conf.to_mail( ERB::new( rmail ).result( binding ) )
 	comment_mail( text, receivers )
 end
 
@@ -821,7 +820,7 @@ end
 def theme_list_local(list)
 	Dir::glob( theme_paths_local ).sort.map {|dir|
 		theme = dir.sub( %r[.*/theme/], '')
-		next unless FileTest::file?( "#{dir}/#{theme}.css".untaint )
+		next unless FileTest::file?( "#{dir}/#{theme}.css" )
 		name = theme.split( /_/ ).collect{|s| s.capitalize}.join( ' ' )
 		list << ["local/#{theme}",name]
 	}
